@@ -318,6 +318,11 @@ void MenuBarApplet::slotWindowRegistered(WId wid, const QString& service, const
     mImporters.insert(wid, importer);
     connect(importer, SIGNAL(actionActivationRequested(QAction*)), SLOT(slotActionActivationRequested(QAction*)));
     QMetaObject::invokeMethod(importer, "updateMenu", Qt::QueuedConnection);
+
+    // If the window is already active, create the menubar (Happens with GTK apps)
+    if (KWindowSystem::activeWindow() == wid) {
+        createMenuBar();
+    }
 }
 
 void MenuBarApplet::slotWindowUnregistered(WId wid)
